"""
@author:  Patrice Neff
@since:   2004-03-28
@license: GNU General Public License
@version: $Revision: 1.2 $

Store a recent files list in the configuration.
"""

class RecentFiles:
    """Does the handling of recently opened files. Stores up to four
    recent files.

    @since: 2004-03-28
    """
    def __init__(self, config):
        """Class constructor.

        @param config: Configuration object to use.
        @type config: L{wxConfig}
        """
        self.__config = config
        self.loadList()

    def loadList(self):
        """Load the list of recently opened items into memory.
        """
        recent = []
        for i in range(1, 5):
            recent.append(self.__config.Read("/Recent/" + str(i) + "/Path"))
        self.__recent = recent

    def saveList(self):
        """Save the in-memory list back.
        """
        i = 0
        for recent in self.__recent:
            i+=1
            self.__config.Write("/Recent/" + str(i) + "/Path", recent)

    def addFile(self, filename):
        """Add a new file to the recent files list.

        @param filename: Filename to add
        @type filename: String
        """
        if filename == "":
            return
        
        recent = self.__recent
        if not filename in recent:
            end = len(recent)-1
        else:
            for i, item in enumerate(recent):
                if item == filename:
                    end = i
                    break

        for i in range(end, 0, -1):
            recent[i] = recent[i-1]
        recent[0] = filename
        self.saveList()

    def getList(self):
        return self.__recent
