"""
@author:  Patrice Neff
@since:   2004-02-14
@license: GNU General Public License
@version: $Revision: 1.3 $

XML helper functions.
"""

import types
import xml.sax.saxutils

def att_enc(str):
    """Escape the value for use in attribute data. The value is
    encoded in UTF-8 and surrounded with quotes. Special characters
    are escaped.

    @param str: String to treat
    @type str: Unicode string
    @return: Encoded and escape string
    @rtype: UTF-8 encoded string
    @raise TypeError: If str is not a unicode object
    """
    if not isinstance(str, types.UnicodeType):
        raise TypeError("str is not a unicode object")
    return xml.sax.saxutils.quoteattr(str).encode('UTF-8')

def chr_enc(str):
    """Escape the value for use in element data. The value is encoded
    in UTF-8 and and special characters are escaped.

    @param str: String to treat
    @type str: Unicode string
    @return: Encoded and escape string
    @rtype: UTF-8 encoded string
    @raise TypeError: If str is not a unicode object
    """
    if not isinstance(str, types.UnicodeType):
        raise TypeError("str is not a unicode object")
    return xml.sax.saxutils.escape(str).encode('UTF-8')
