"""
@author:  Patrice Neff
@since:   2004-04-09
@license: GNU General Public License
@version: $Revision: 1.3 $

Some helper classes for using the wxPython.
"""

from wxPython.wx import *

class ErrorDialog:
    """Shows an error message to the user.

    @since: 2004-04-09
    """
    def __init__(self, message, title = ""):
        """Constructor. Shows the message to the user.

        @param message: Text to show
        @type message: String
        @param title: Optional title for the window.
        @type title: String
        """
        if title == "":
            title = "Error"
        dlg = wxMessageDialog(None, message, title,
                              wxOK | wxICON_ERROR)
        dlg.ShowModal()
        dlg.Destroy()

class QuestionDialog:
    """Asks the user a yes/no question.

    @since: 2004-04-09
    """
    def __init__(self, message, title = ""):
        """Constructor. Shows the message to the user and presents the
        two buttons Yes and No.

        @param message: Text to show
        @type message: String
        @param title: Optional title for the window.
        @type title: String
        """
        if title == "":
            title = "Question"
        dlg = wxMessageDialog(None, message, title,
                              wxYES_NO | wxICON_QUESTION )
        self.__answer = dlg.ShowModal()
        dlg.Destroy()

    def getAnswer(self):
        """Return the answer which was given by the user.

        @return: Answer
        @rtype: Either wxID_YES or wxID_NO
        """
        return self.__answer

def uconv(string):
	"""Returns the unicode version of the string. If the string is already unicode, it is returned unchanged."""
	if string.__class__ == unicode:
		return string
	else:
		return unicode(string, "iso-8859-15")
